==> asc_2.0.1.0.orig.tar.gz: asc-2.0.1.0/source/dialogs/fileselector.h <==
/*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
     Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
     along with this program; see the file COPYING. If not, write to the 
     Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
     Boston, MA  02111-1307  USA
*/

#ifndef FILESELECTOR_H
#define FILESELECTOR_H

#include "selectionwindow.h"
#include "../paradialog.h"

class FileInfo;
class FileSelectionItemFactory;

class FileSelectionWindow : public ASC_PG_Dialog {
      ASCString filename;
      ASCString wildcard;
      bool saveFile;
      FileSelectionItemFactory* factory;

   protected:
      void fileNameSelected( const ASCString& filename );
      void fileNameEntered( ASCString filename );
   public:
      FileSelectionWindow( PG_Widget *parent, const PG_Rect &r, const ASCString& fileWildcard, bool save );
      ASCString getFilename() { return filename; };
};


class FileSelectionItemFactory: public SelectionItemFactory  {
   protected:
      typedef deallocating_vector<FileInfo*> Items;
      Items::iterator it;

   private:      
      Items items;
      
   public:
      FileSelectionItemFactory( const ASCString& wildcard );
      
      static bool comp ( const FileInfo* i1, const FileInfo* i2 );

      void restart();

      int getLevel( const ASCString& name );
      
      SelectionWidget* spawnNextItem( PG_Widget* parent, const PG_Point& pos );
      
      SigC::Signal1<void,const ASCString& > filenameSelectedMouse;
      SigC::Signal1<void,const ASCString& > filenameSelectedKeyb;
      SigC::Signal1<void,const ASCString& > filenameMarked;
      
      void itemMarked( const SelectionWidget* widget );
      
      void itemSelected( const SelectionWidget* widget, bool mouse );
};

extern ASCString  selectFile( const ASCString& ext, bool load );

#endif

==> asc_2.4.0.0.orig.tar.gz: asc-2.4.0.0/source/dialogs/fileselector.h <==
/*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
     Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
     along with this program; see the file COPYING. If not, write to the 
     Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
     Boston, MA  02111-1307  USA
*/

#ifndef FILESELECTOR_H
#define FILESELECTOR_H

#include "selectionwindow.h"
#include "../paradialog.h"

class FileInfo;
class FileSelectionItemFactory;

class FileSelectionWindow : public ASC_PG_Dialog {
      ASCString filename;
      ASCString wildcard;
      bool saveFile;
      bool overwriteMessage;
      FileSelectionItemFactory* factory;

   protected:
      void fileNameSelected( const ASCString& filename );
      void fileNameEntered( ASCString filename );
   public:
      FileSelectionWindow( PG_Widget *parent, const PG_Rect &r, const ASCString& fileWildcard, bool save, bool overwriteMessage );
      ASCString getFilename() { return filename; };
};


class FileSelectionItemFactory: public SelectionItemFactory  {
   protected:
      typedef deallocating_vector<FileInfo*> Items;
      Items::iterator it;

   private:      
      Items items;
      
   public:
      FileSelectionItemFactory( const ASCString& wildcard );
      
      static bool comp ( const FileInfo* i1, const FileInfo* i2 );

      void restart();

      int getLevel( const ASCString& name );
      
      SelectionWidget* spawnNextItem( PG_Widget* parent, const PG_Point& pos );
      
      SigC::Signal1<void,const ASCString& > filenameSelectedMouse;
      SigC::Signal1<void,const ASCString& > filenameSelectedKeyb;
      SigC::Signal1<void,const ASCString& > filenameMarked;
      
      void itemMarked( const SelectionWidget* widget );
      
      void itemSelected( const SelectionWidget* widget, bool mouse );
};

extern ASCString  selectFile( const ASCString& ext, bool load, bool overwriteMessage = true );

#endif
